@@ -69,6 +69,7 @@ from typeguard import check_type
 
 from ._jsii import *
 
+import aws_cdk.aws_route53
 import constructs
 
 
@@ -85,6 +86,7 @@ class HugoDeploy(
         domain_name: builtins.str,
         public_dir: builtins.str,
         region: typing.Optional[builtins.str] = None,
+        zone: typing.Optional[aws_cdk.aws_route53.HostedZone] = None,
     ) -> None:
         '''
         :param scope: -
@@ -92,13 +94,14 @@ class HugoDeploy(
         :param domain_name: Domain name of the site deploying to. You should already have a hosted zone in the account you're deploying to with this domain name
         :param public_dir: Path to Hugo public directory, which is generated after running the ``hugo`` command. By default, this will be the ``public`` directory in your hugo project
         :param region: Region deploying to. Default: - us-east-1
+        :param zone: Zone the Domain Name is created in.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(HugoDeploy.__init__)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = HugoDeployProps(
-            domain_name=domain_name, public_dir=public_dir, region=region
+            domain_name=domain_name, public_dir=public_dir, region=region, zone=zone
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -126,6 +129,7 @@ class HugoDeploy(
         "domain_name": "domainName",
         "public_dir": "publicDir",
         "region": "region",
+        "zone": "zone",
     },
 )
 class HugoDeployProps:
@@ -135,23 +139,28 @@ class HugoDeployProps:
         domain_name: builtins.str,
         public_dir: builtins.str,
         region: typing.Optional[builtins.str] = None,
+        zone: typing.Optional[aws_cdk.aws_route53.HostedZone] = None,
     ) -> None:
         '''
         :param domain_name: Domain name of the site deploying to. You should already have a hosted zone in the account you're deploying to with this domain name
         :param public_dir: Path to Hugo public directory, which is generated after running the ``hugo`` command. By default, this will be the ``public`` directory in your hugo project
         :param region: Region deploying to. Default: - us-east-1
+        :param zone: Zone the Domain Name is created in.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(HugoDeployProps.__init__)
             check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
             check_type(argname="argument public_dir", value=public_dir, expected_type=type_hints["public_dir"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
+            check_type(argname="argument zone", value=zone, expected_type=type_hints["zone"])
         self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
             "public_dir": public_dir,
         }
         if region is not None:
             self._values["region"] = region
+        if zone is not None:
+            self._values["zone"] = zone
 
     @builtins.property
     def domain_name(self) -> builtins.str:
@@ -182,6 +191,12 @@ class HugoDeployProps:
         result = self._values.get("region")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def zone(self) -> typing.Optional[aws_cdk.aws_route53.HostedZone]:
+        '''Zone the Domain Name is created in.'''
+        result = self._values.get("zone")
+        return typing.cast(typing.Optional[aws_cdk.aws_route53.HostedZone], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
